@@ -9,7 +9,7 @@ from aiortc import RTCPeerConnection, RTCRtpSender, RTCConfiguration, RTCIceServ
 from aiortc.contrib.media import MediaPlayer, MediaRelay
 import picamera
 
-from pitrack import PiH264Relay, PiH264CameraOutput
+from gspeerconnection.pitrack import PiH264Relay, PiH264CameraOutput
 
 video_trackList = list()
 
@@ -95,7 +95,6 @@ class GSPeerConnectionBroadcaster:
 
                 self.peerConnections[id] = pc
 
-
                 video = self.getPiH264Relay()
 
                 @pc.on("iceconnectionstatechange")
@@ -116,7 +115,6 @@ class GSPeerConnectionBroadcaster:
                     if t.kind == "video":
                         pc.addTrack(video)
 
-
                 await pc.setLocalDescription(await pc.createOffer())
                 await self.sio.emit("offer", {"id": id,
                                               "message": json.dumps(
