@@ -6,32 +6,36 @@ import socketio
 from aiortc import MediaStreamTrack, RTCPeerConnection
 from aiortc.rtcrtpreceiver import RemoteStreamTrack
 
+from pitrack import PiH264Relay
+
 
 class GSPeerConnectionWatcher:
-    class VideoTransformTrack(MediaStreamTrack):
+    class PiH264Relay(MediaStreamTrack):
         kind = "video"
 
-        def __init__(self, track:RemoteStreamTrack, gsdbs, source, onframe):
+        def __init__(self, track: RemoteStreamTrack, gsdbs, source, onframe):
             super().__init__()
             self.track = track
             self.onframe = onframe
             self.source = source
             self.gsdbs = gsdbs
 
+        #
         async def recv(self):
             # frame = await self.track.recv()
             frame = await self.track._queue.get()
-            self.onframe(self.gsdbs, self.source, frame)
+            # self.onframe(self.gsdbs, self.source, frame)
             return frame
 
     @classmethod
-    async def create(cls, gsdbs, target, onframe, onmessage):
+    async def create(cls, gsdbs, target, onframe=None, onmessage=None, ontrack=None):
         self = GSPeerConnectionWatcher()
         self.sio = socketio.AsyncClient()
         self.gsdbs = gsdbs
         self.onframe = onframe
         self.target = target
         self.onmessage = onmessage
+        self.ontrack = ontrack
         self.logger = logging.getLogger(__name__)
 
         @self.sio.event
@@ -64,8 +68,11 @@ class GSPeerConnectionWatcher:
             @self.peerConnections.on("track")
             def on_track(track):
                 if track.kind == "video":
-                    local_video = self.VideoTransformTrack(track, gsdbs=self.gsdbs, source=self.target,
-                                                           onframe=self.onframe)
+                    if self.ontrack is not None:
+                        self.ontrack(self.gsdbs, track)
+                    # local_video = self.VideoTransformTrack(track, gsdbs=self.gsdbs, source=self.target,
+                    #                                        onframe=self.onframe)
+                    local_video = PiH264Relay(30)
                     self.peerConnections.addTrack(local_video)
 
                 @track.on("ended")
